/*
* Copyright (C) 2011 Sunil Mohan Adapa <sunil@medhas.org>.
* Copyright (C) 2011 O S K Chaitanya <oskchaitanya@gmail.com>.
*
* Author: Sunil Mohan Adapa <sunil@medhas.org>
*         O S K Chaitanya <oskchaitanya@gmail.com>
*
* This file is part of GNOME Nonogram.
*
* GNOME Nonogram is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* GNOME Nonogram is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with GNOME Nonogram. If not, see <http://www.gnu.org/licenses/>.
*/

const Lang = imports.lang;
const GObject = imports.gi.GObject;
const Gio = imports.gi.Gio;
const Gtk = imports.gi.Gtk;

const Config = imports.config;

DashboardWidget = new GType(_DashboardWidget = {
    parent: Gtk.HPaned.type,
    name: "DashboardWidget",

    _puzzleSetsListStore: null,

    class_init: function(klass, prototype) {
        prototype._puzzleSetsListStore = _DashboardWidget._puzzleSetsListStore;

        prototype.connectSignalsAndChildren =
            _DashboardWidget.connectSignalsAndChildren;
        prototype._acquireChildren = _DashboardWidget._acquireChildren;
        prototype._scanForPuzzleSets = _DashboardWidget._scanForPuzzleSets;
        prototype._onRealize = _DashboardWidget._onRealize;
    },

    init: function() {
        this.signal.realize.connect(Lang.bind(this, this._onRealize));
    },

    connectSignalsAndChildren: function(builder) {
        this._acquireChildren(builder);
    },

    _acquireChildren: function(builder) {
        this._puzzleSetsListStore =
            builder.get_object("puzzle_sets_liststore");
    },

    _onRealize: function() {
        this._scanForPuzzleSets(Config.datadir + "/puzzles/");
    },

    _scanForPuzzleSets: function(directoryPath) {
        var directory = Gio.file_new_for_path(directoryPath);
        var attributes = Gio.FILE_ATTRIBUTE_STANDARD_DISPLAY_NAME + ","
                       + Gio.FILE_ATTRIBUTE_STANDARD_NAME;
        var enumerator = directory.enumerate_children(attributes, 0);

        while (1) {
            var fileInfo = enumerator.next_file();
            if (fileInfo == null)
               break;

            print("dirname = '" + fileInfo.get_name());
/* TODO: replace this with C interface call since we are unable to set gvalue
 *       like this without crashing seed
            var newRow = this._puzzleSetsListStore.append();
            this._puzzleSetsListStore.set_value(newRow.iter,
                0, [GObject.String.type, fileInfo.get_name()]);
*/
        }
    }
});
